summaryrefslogtreecommitdiffstats
path: root/korn/dockeditem.h
diff options
context:
space:
mode:
Diffstat (limited to 'korn/dockeditem.h')
-rw-r--r--korn/dockeditem.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/korn/dockeditem.h b/korn/dockeditem.h
index ddb6b0d7..e375bb97 100644
--- a/korn/dockeditem.h
+++ b/korn/dockeditem.h
@@ -23,7 +23,7 @@
class SystemTray;
-class KConfig;
+class TDEConfig;
class TQPixmap;
@@ -58,10 +58,10 @@ public:
* This functions reads the config. It used the parent
* version for the main things, but it is possible to
* add some configurations over here.
* @param config The KConfig-instance which contains the settings of this tray-item.
* @param index The index of the box in the configuration file
*/
- virtual void readConfig( KConfig* config, const int index );
+ virtual void readConfig( TDEConfig* config, const int index );
public slots:
/**
@@ -58,10 +58,10 @@ public:
* version for the main things, but it is possible to
* add some configurations over here.
- * @param config The KConfig-instance which contains the settings of this tray-item.
+ * @param config The TDEConfig-instance which contains the settings of this tray-item.
* @param index The index of the box in the configuration file
*/